/******************************************************************************
*   @file   adf4002.h
*   @brief  Header file of ADF4002 Driver for NIOS processor.
*   @author ACostina (adrian.costina@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 796
******************************************************************************/
#ifndef _ADF4002_H_
#define _ADF4002_H_
#ifdef ADF4002_GLOBALS
    #define ADF4002_EXT extern volatile
#else
    #define ADF4002_EXT volatile
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "adi.h"
#if (USE_ADF4002 == 1)

/*****************************************************************************/
/* ADF4002                                                                    */
/*****************************************************************************/
//Control Bits
#define CTRL_R_COUNTER                  0
#define CTRL_N_COUNTER                  1
#define CTRL_FUNCTION_LATCH             2
#define CTRL_INIT_LATCH                 3

//Reference Counter Latch register
#define ADF4002_R_COUNTER_POSITION      2
#define ADF4002_R_ABW_2_9n              (0 << 16)
#define ADF4002_R_ABW_1_3n              (1 << 16)
#define ADF4002_R_ABW_6_0n              (2 << 16)

#define ADF4002_R_TMB_NORMAL            (0 << 18)

#define ADF4002_R_LDP_3                 (0 << 20)
#define ADF4002_R_LDP_5                 (1 << 20)

//N Counter Latch register
#define ADF4002_N_COUNTER_POSITION      8

#define ADF4002_N_CP_SETTING_1          (0 << 21)
#define ADF4002_N_CP_SETTING_2          (1 << 21)

//Function Latch register
#define ADF4002_F_CR_NORMAL             (0 << 2)
#define ADF4002_F_CR_RESET              (1 << 2)

#define ADF4002_F_PD1_NORMAL            (0 << 3)
#define ADF4002_F_PD1_RESET             (1 << 3)

#define ADF4002_F_MUXOUT_TRISTATE       (0 << 4)
#define ADF4002_F_MUXOUT_DLD            (1 << 4)
#define ADF4002_F_MUXOUT_NDIV           (2 << 4)
#define ADF4002_F_MUXOUT_AVDD           (3 << 4)
#define ADF4002_F_MUXOUT_RDIV           (4 << 4)
#define ADF4002_F_MUXOUT_NCODLD         (5 << 4)
#define ADF4002_F_MUXOUT_SDO            (6 << 4)
#define ADF4002_F_MUXOUT_DGND           (7 << 4)

#define ADF4002_F_PDPOL_NEGATIVE        (0 << 7)
#define ADF4002_F_PDPOL_POSITIVE        (1 << 7)

#define ADF4002_F_CPTS_NORMAL           (0 << 8)
#define ADF4002_F_CPTS_THREE_STATE      (1 << 8)

#define ADF4002_F_FASTLOCK_DISABLE      (0 << 9)
#define ADF4002_F_FASTLOCK_MODE1        (2 << 9)
#define ADF4002_F_FASTLOCK_MODE2        (3 << 9)

#define ADF4002_F_TCC_3                 (0 << 11)
#define ADF4002_F_TCC_7                 (1 << 11)
#define ADF4002_F_TCC_11                (2 << 11)
#define ADF4002_F_TCC_15                (3 << 11)
#define ADF4002_F_TCC_19                (4 << 11)
#define ADF4002_F_TCC_23                (5 << 11)
#define ADF4002_F_TCC_27                (6 << 11)
#define ADF4002_F_TCC_31                (7 << 11)
#define ADF4002_F_TCC_35                (8 << 11)
#define ADF4002_F_TCC_39                (9 << 11)
#define ADF4002_F_TCC_43                (10 << 11)
#define ADF4002_F_TCC_47                (11 << 11)
#define ADF4002_F_TCC_51                (12 << 11)
#define ADF4002_F_TCC_55                (13 << 11)
#define ADF4002_F_TCC_59                (14 << 11)
#define ADF4002_F_TCC_63                (15 << 11)

#define ADF4002_F_CS1_POSITION          15
#define ADF4002_F_CS2_POSITION          18

#define ADF4002_F_PD2_NORMAL            (0 << 21)
#define ADF4002_F_PD2_RESET             (1 << 21)

//Initialization register
#define ADF4002_I_CR_NORMAL             (0 << 2)
#define ADF4002_I_CR_RESET              (1 << 2)

#define ADF4002_I_PD1_NORMAL            (0 << 3)
#define ADF4002_I_PD1_RESET             (1 << 3)

#define ADF4002_I_MUXOUT_TRISTATE       (0 << 4)
#define ADF4002_I_MUXOUT_DLD            (1 << 4)
#define ADF4002_I_MUXOUT_NDIV           (2 << 4)
#define ADF4002_I_MUXOUT_AVDD           (3 << 4)
#define ADF4002_I_MUXOUT_RDIV           (4 << 4)
#define ADF4002_I_MUXOUT_NCODLD         (5 << 4)
#define ADF4002_I_MUXOUT_SDO            (6 << 4)
#define ADF4002_I_MUXOUT_DGND           (7 << 4)

#define ADF4002_I_PDPOL_NEGATIVE        (0 << 7)
#define ADF4002_I_PDPOL_POSITIVE        (1 << 7)

#define ADF4002_I_CPTS_NORMAL           (0 << 8)
#define ADF4002_I_CPTS_THREE_STATE      (1 << 8)

#define ADF4002_I_FASTLOCK_DISABLE      (0 << 9)
#define ADF4002_I_FASTLOCK_MODE1        (2 << 9)
#define ADF4002_I_FASTLOCK_MODE2        (3 << 9)

#define ADF4002_I_TCC_3                 (0 << 11)
#define ADF4002_I_TCC_7                 (1 << 11)
#define ADF4002_I_TCC_11                (2 << 11)
#define ADF4002_I_TCC_15                (3 << 11)
#define ADF4002_I_TCC_19                (4 << 11)
#define ADF4002_I_TCC_23                (5 << 11)
#define ADF4002_I_TCC_27                (6 << 11)
#define ADF4002_I_TCC_31                (7 << 11)
#define ADF4002_I_TCC_35                (8 << 11)
#define ADF4002_I_TCC_39                (9 << 11)
#define ADF4002_I_TCC_43                (10 << 11)
#define ADF4002_I_TCC_47                (11 << 11)
#define ADF4002_I_TCC_51                (12 << 11)
#define ADF4002_I_TCC_55                (13 << 11)
#define ADF4002_I_TCC_59                (14 << 11)
#define ADF4002_I_TCC_63                (15 << 11)

#define ADF4002_I_CS1_POSITION          15
#define ADF4002_I_CS2_POSITION          18

#define ADF4002_I_PD2_NORMAL            (0 << 21)
#define ADF4002_I_PD2_RESET             (1 << 21)

//GPIO
#define GPIO_LE                         (1 << 0)
#define GPIO_CE                         (1 << 2)
#define GPIO_LE2                        (1 << 6)
#define GPIO_CE2                        (1 << 7)

/*****************************************************************************/
/* SPI Configuration                                                         */
/*****************************************************************************/
#define ADF4002_SPI      SPI_0_P0_BASE
#define ADF4002_SPI_CFG  (SPI0_ena )

/*****************************************************************************/
/* Monitored variables declarations                                          */
/*****************************************************************************/
ADF4002_EXT uCProbeDataUnion ADF4002_Data[38];    //used to store the values for uC-Probe communication
#endif //(USE_ADF4002 == 1)

/*****************************************************************************/
/*  Functions Prototypes                                                     */
/*****************************************************************************/
int     ADF4002_Init( void );                   //Initialize SPI and the ADF4002 Chip
void    ADF4002_InitLatchMethod( void );        //Initializes the ADF4002 by using the Initialization Latch Method
void    ADF4002_InitCEPinMethod( void );        //Initializes the ADF4002 by using the CE Pin Method
void    ADF4002_InitCounterResetMethod( void ); //Initializes the ADF4002 by using the Counter Reset Method
int     ADF4002_UpdateParameters(void);         //Update the device's monitored and controlled parameters
int ADF4002_Set( volatile int *value );         //Send SPI Data
#endif /* _ADF4002_H_ */
